@@ -2,7 +2,7 @@ def add(a, b):
     return a + b
 
 def div(a, b):
-    return a / b
+    return a // b
 
 def minus(a, b):
     return a - b
