@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import sys
 from nose.exc import SkipTest
 import unittest
@@ -13,6 +14,9 @@ class TestForXunit(unittest.TestCase):
     def test_error(self):
         raise TypeError("oops, wrong type")
     
+    def test_non_ascii_error(self):
+        raise Exception(u"日本")
+    
     def test_output(self):
         sys.stdout.write("test-generated output\n")
 
