@@ -4,13 +4,12 @@ import unittest
 class TestBug105(unittest.TestCase):
 
     def test_load_in_def_order(self):
-        from nose.config import Config
         from nose.loader import TestLoader
 
         where = os.path.abspath(os.path.join(os.path.dirname(__file__),
                                              'support', 'bug105'))
-        c = Config()
-        l = TestLoader(conf=c)
+
+        l = TestLoader()
         testmod = l.loadTestsFromDir(where).next()
         print testmod
         testmod.setUp()
